"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const hoistDevDeps_1 = require("./commands/hoistDevDeps");
const starLocalDevDeps_1 = require("./commands/starLocalDevDeps");
commander_1.program
    .name('better-deps')
    .description('CLI for cleaning up issues with JavaScript dependencies in monorepos/workspaces')
    .version(require('../package.json').version);
const checkOption = new commander_1.Option('--check', 'Check for issues without making any changes, and exit non-zero if issues are found');
function handleResult(res, check) {
    console.log();
    if (!check) {
        console.log(`✅ Updated ${res.length} packages\n`);
    }
    else if (res.length) {
        console.error(`Found ${res.length} packages with new issues!`);
        const command = process.argv
            .slice(2)
            .filter((arg) => arg !== '--check')
            .join(' ');
        console.error(`Run this command to fix them:\n\n  npx better-deps ${command}\n`);
        process.exit(1);
    }
    else {
        console.log('✅ No issues found!\n');
    }
}
commander_1.program
    .command('hoist-dev-deps')
    .description('Hoist devDependencies from individual packages to the workspace root')
    .addOption(checkOption)
    .option('--exclude <deps...>', "Don't hoist these devDependencies")
    .addOption(new commander_1.Option('--only <deps...>', 'Only hoist these devDependencies (mutually exclusive with other options)').conflicts(['always', 'exclude', 'threshold']))
    .addOption(new commander_1.Option('--threshold <percent>', 'Only hoist devDependencies used in >= this % of packages')
    .default(0, '0, hoist everything')
    .conflicts(['only'])
    .argParser((value) => {
    const numValue = Number(value);
    if (isNaN(numValue) || numValue < 0 || numValue > 100)
        throw new commander_1.InvalidArgumentError('Must be a number between 0 and 100 (inclusive).');
    // interpret threshold <= 1 as a percentage
    return numValue <= 1 ? numValue : numValue / 100;
}))
    .option('--always <deps...>', 'Always hoist these devDependencies (only relevant with --threshold)')
    .action(({ check, ...options }) => {
    const res = (0, hoistDevDeps_1.hoistDevDeps)({ ...options, write: !check });
    handleResult(res, !!check);
});
commander_1.program
    .command('star-local-dev-deps')
    .description('Change version specs of devDependencies on local packages to "*"')
    .addOption(checkOption)
    .action(({ check }) => {
    const res = (0, starLocalDevDeps_1.starLocalDevDeps)(!check);
    handleResult(res, !!check);
});
commander_1.program.parse();
